/* 
         Quasi-Two-Dimensional  (J1-J2-chains coupled via J3)

      Data-File: ../Data/Quasi_2D_j1j2j3.ccm

      define Alpha as 1 in solve.C to activate this file
 
    *-------*-------*-------*-------*
   1|      2|      3|      4|      5|
  J3|       |       |       |       |
    |       |       |       |       |
    |       |       |       |       |                   J2
    *-------*-------*-------*-------*            *-------*-------*
   1|   J1 2|      3|      4|      5|            2               4
    |       |       |       |       |
    |       |       |       |       |
    |       |       |       |       |                
    *-------*-------*-------*-------*
   1        2        3       4      5

    bond1 = J2 = Delta    Pi+2*alpha
    bond2 = J1            Pi+  alpha
    bond3 = J3            Pi
  
    LC-case: J3=0, J2=0, phi1=Pi Eg(4-4)=-0.66366391 ???

*/

double usr_angle(int bond, int term13, double *alpha, int numalpha)
{

  double mult = 0.0;  // default for term13 = {10,11,12,13}
  double       phi1 = M_PI +   alpha[0]; // + M_PI was in the script ???
  double       phi2 = M_PI + 2*alpha[0]; // nn-neigbour 
  const double phi3 = M_PI +          0; // Neel-State
  //  cos(alpha)    ==  -cos(M_PI+alpha)
  //  sin(alpha)    ==  -sin(M_PI+alpha)
  // (cos(alpha)+1) == -(cos(M_PI+alpha)-1)  
  // double j2 = 0.0;
  
  if (bond==1) {   // J1 bit now...
    // delta term
    // here it's J_2 coefficients for the 1D spiral J_1--J_2 model
    // now the J_2 part
    if      (term13 ==  1) mult=       cos(phi2);    // s^z s^z 
    else if (term13 ==  2) mult=   0.5*sin(phi2);    // s^z s^+ 
    else if (term13 ==  3) mult=   0.5*sin(phi2);    // s^z s^- 
    else if (term13 ==  4) mult=  -0.5*sin(phi2);    // s^+ s^z
    else if (term13 ==  5) mult=  -0.5*sin(phi2);    // s^- s^z
    else if (term13 ==  6) mult= 0.25*(cos(phi2)+1); // s^+ s^-
    else if (term13 ==  7) mult= 0.25*(cos(phi2)+1); // s^- s^+
    else if (term13 ==  8) mult= 0.25*(cos(phi2)-1); // s^+ s^+
    else if (term13 ==  9) mult= 0.25*(cos(phi2)-1); // s^- s^-
    /* 10..13 ??? (magnetic field, see lc_mf) */
  } else if (bond==2) {  // J_2 bit now...
    if      (term13 ==  1) mult=       cos(phi1); // -cos -> cos Oct05
    else if (term13 ==  2) mult=   0.5*sin(phi1);
    else if (term13 ==  3) mult=   0.5*sin(phi1);
    else if (term13 ==  4) mult=  -0.5*sin(phi1);
    else if (term13 ==  5) mult=  -0.5*sin(phi1);
    else if (term13 ==  6) mult= 0.25*(cos(phi1)+1); // Oct05: -cos
    else if (term13 ==  7) mult= 0.25*(cos(phi1)+1);
    else if (term13 ==  8) mult= 0.25*(cos(phi1)-1);
    else if (term13 ==  9) mult= 0.25*(cos(phi1)-1);
  } else {   // J_3 bit now...
    if      (term13 ==  1) mult=       cos(phi3); // Oct05: -cos 
    else if (term13 ==  2) mult=   0.5*sin(phi3);
    else if (term13 ==  3) mult=   0.5*sin(phi3);
    else if (term13 ==  4) mult=  -0.5*sin(phi3);
    else if (term13 ==  5) mult=  -0.5*sin(phi3);
    else if (term13 ==  6) mult= 0.25*(cos(phi3)+1);
    else if (term13 ==  7) mult= 0.25*(cos(phi3)+1);
    else if (term13 ==  8) mult= 0.25*(cos(phi3)-1);
    else if (term13 ==  9) mult= 0.25*(cos(phi3)-1);
  }                                                                     
  return mult;
}
